# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.cash_pay_payer_error_message import CashPayPayerErrorMessage


class CashPayPayerError(ApiError):
    def __init__(self, body: CashPayPayerErrorMessage):
        super().__init__(status_code=422, body=body)
