# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ......core.datetime_utils import serialize_datetime
from .lab_code_type import LabCodeType

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class Lab(pydantic.BaseModel):
    """
    from candid.resources.encounters.v_4 import Lab, LabCodeType

    Lab(
        name="Genetic Health Labs",
        code="GH12345",
        code_type=LabCodeType.QUEST,
    )
    """

    name: str
    code: typing.Optional[str] = None
    code_type: typing.Optional[LabCodeType] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
